@@ -1,6 +1,6 @@
 __name__ = 'keras_htr'
-__version__ = '0.0.1'
+__version__ = '0.1.0.post1'
 __author__ = 'Evgenii Dolotov'
 __author_email__ = 'supernovaprotocol@gmail.com'
 __description__ = 'A toolkit for developing handwritten text recognition (HTR) pipelines'
-__url__ = ''
+__url__ = 'https://github.com/X-rayLaser/Keras-HTR'
